==> vera-1.4a.tar.gz: vera-1.4a/vera.h <==
@c Syntax:
@c ACRONYM
@c Expansion[ (Reference)][, "Style"]
@c Additional explanations are included in [square brackets]

@table @asis
@item H4P
High Performance Parallel Processing Project (ICI)

@item HACMP
High Availability Clustered Multi Processing (IBM, RS/6000, Bull), "HA/CMP"

@item HAL
Hard Array Logic

@item HAL
Hardware Abstraction Layer Windows NT

@item HAL
Heuristically programmed ALgorithmic computer (2001)

@item HALPC
Houston Area League of PC-Users, "HAL-PC"

@item HAMPS
Host AUTODIN Message Processing System AUTODIN, mil.

@item HAND
Have A Nice Day slang, Usenet, IRC

@item HANFS
Highly Available Network File System

@item HAP
Host Access Protocol (RFC 907/1221)

@item HAS
High Availability Subsystem (Bull)

@item HAT
Hashed Address Table

@item HBA
Host Bus Adapter (SCSI)

@item HBCI
HomeBanking Computer Interface Internet, banking

@item HCI
Human Computer Interaction BCS, conference

@item HCL
Host Control Links

@item HCSDS
High Capacity Satellite Digital Service

@item HCSS
High Capacity Storage System (Novell, Netware)

@item HCT
Hamburger ComputerTage fair

@item HCT
High-speed CMOS [logic] with TTT-compatible [logic] levels (IC, MOS)

@item HCTDS
High-Capacity Terrestrial Digital Service

@item HD
High Density

@item HDB
HoneyDanBer [standard] (Unix)

@item HDB3
High Density Bipolar 3

@item HDBMS
Hierarchical DataBase Management System (DBMS, DB)

@item HDC
Hard Disk Controller

@item HDCD
High Density Compact Disk (CD, Sony, Phillips)

@item HDD
Hard Disk Drive

@item HDF
Hierarchical Data Format (NCSA)

@item HDH
HDLC Distant Host

@item HDI
HOOPS Device Interface (VAGI)

@item HDL
Hardware Description Language (ASIC)

@item HDLC
High-level Data Link Control (ISO)

@item HDM
Hardware Device Module (I2O)

@item HDN
Hochgeschwindigkeits-DatenNetz

@item HDR
High availability Data Replication (Informix, DB)

@item HDR
High Dynamic Range

@item HDSL
High data / bit rate Digital Subscriber Line (BELLCORE, AT&T, DSL)

@item HDSL
High-level Data Specification Language

@item HDX
Half DupleX

@item HEA
Hyundai Electronics of America manufacturer

@item HEC
Header Error Check

@item HEC
Header Error Control (ATM)

@item HECTOR
HEterogeneous Computer TOgetheR IBM, Uni Karlsruhe, Germany

@item HEL
Hardware Emulation Layer

@item HEL
Header Extension Length

@item HEMT
High Electron Mobility Transistor

@item HEPNET
High Energy Physics NETwork network

@item HERMES
Heuristic Emergency Response Management Expert System (XPS)

@item HERODE
Handling the Electronic Representation of mixed text - image Office Documents based on ECMA standard 101 (ESPRIT, SNI, TITN, ECMA, ODA)

@item HES
Home Electronic System (SNI)

@item HFD
Hauptanschluss fuer Direktruf / Datenleitung (Telekom), "HfD"

@item HFDS
Highly Functional Distributed System (MTRON)

@item HFS
Hierachical File System (Apple, CD)

@item HFT
High Function Terminal (AIX, IBM)

@item HGA
Hercules Graphics Adapter

@item HGC
Hercules Graphics Card

@item HHI
Heinrich Hertz Institut org., Deutschland

@item HI
Hochschulverband Informationswissenschaften org.

@item HIC
Human Interaction Component

@item HIC
Hybrid Integrated Circuit

@item HID
Human Interface Device (MS)

@item HIFD
HIgh capacity Floppy Disk (Sony, Fuji), "HiFD"

@item HIFI
Hypertext Interface For Information (ESPRIT)

@item HIFIVE
HIgh Fidelity Interactive Visual Environment (DEC), "Hi-FIVE"

@item HIFT
Hardware Implemented Fault Tolerance (SIFT)

@item HIGGENS
Human Interface Graphical GENeration System (Uni Colorado)

@item HINT
Hierarchical INTegration [benchmark]

@item HIPPI
HIgh Performance Parallel Interface

@item HIPPI
High Performance Peripheral Interface

@item HIRD
HURD of Interface Representing Depth (GNU, HURD)

@item HISP
HIgh SPeed channel connector (Cray, I/O)

@item HLL
High Level Language

@item HLLAPI
High Level Language Application Programming Interface (IBM, API)

@item HLPI
Higher Layer Protocol Identifier

@item HLR
Home Location Register (LR, GSM)

@item HLS
Hue, Luminance, Saturation color system, DTP

@item HMA
High Memory Area

@item HMAC
keyed-Hashing for Message AuthentiCation cryptography, RFC 2104

@item HMC
Highspeed Memory Controller (Apple)

@item HMD
Head Mounted Display (VR)

@item HMI
Human-Machine Interface

@item HMMP
HyperMedia Management Protocol (MS, Intel, Cisco, WWW, HMMS)

@item HMMS
HyperMedia Management Schema (MS, Intel, Cisco, WWW)

@item HMOS
High performance Metal Oxide Semiconductor (IC)

@item HMP
Host Monitoring Protocol (RFC 869)

@item HMUX
Hybrid MUltipleXer (FDDI), "H-MUX"

@item HNF
Heinz Nixdorf Museumsforum org., Paderborn

@item HNI
Heinz Nixdorf Institut org., ZIT

@item HOL
Head Of Line

@item HOOPS
Hierarchical Object Orientated Picture System (Ithaca, Autodesk, OOP)

@item HP
Hewlett Packard manufacturer

@item HPBIDS
Hewlett Packard Broadband Internet Delivery System (HP, Internet), "HP BIDS"

@item HPC
High Performance Computing

@item HPCC
High Performance Computing and Communication

@item HPCS
High Performance Communication Server (Tobit, NLM, Netware)

@item HPF
High Performance FORTRAN (FORTRAN)

@item HPFS
High Performance FileSystem (OS/2)

@item HPGL
Hewlett Packard Graphics Language (CAD, CAM, HP)

@item HPIB
Hewlett Packard Interface Bus

@item HPM
Hyper Page Mode

@item HPMI
??? [Schnittstelle] (CAD), "HP-MI"

@item HPOFS
High Performance Optical File System (IBM, OS/2, MOD)

@item HPPA
Hewlett Packard Precision Architecture (HP, RISC)

@item HPPCL
Hewlett Packard Printer Control Language

@item HPR
High Priority Request (VUMA)

@item HPTS
High Performance Transaction Systems

@item HPUX
Hewlett Packard / UniX (Unix), "HP/UX"

@item HPVEE
Hewlett Packard ??? (HP), "HP VEE"

@item HPVUE
Hewlett Packard - Visual User Environment (HP, GUI), "HP-VUE"

@item HRC
Hybrid Ring Control (FDDI)

@item HS
High Speed (MODEM)

@item HSA
High Speed Access

@item HSB
Hue Saturation Brightness (DTP)

@item HSC
Hierarchical Storage Controller

@item HSFS
High Sierra File System

@item HSI
High Speed Interface

@item HSI
Hue, Saturation, Intensity (DTP)

@item HSIS
??? High Speed Interface / SNA, "HSI/S"

@item HSLAN
High Speed Local Area Network, "HS-LAN"

@item HSLFX
??? [hardware description language] (HDL, NTT, LSI), "HSL-FX"

@item HSLN
High Speed Local Network

@item HSM
Hardware Specific Module (ODI)

@item HSM
Hierarchical Storage Management

@item HSM
Hierarchisches SpeicherManagement

@item HSRP
Hot Standby Router Protocol (Cisco, IOS)

@item HSSDS
High-Speed Switched Digital Service

@item HSSI
High Speed Serial Interface

@item HSSN
HighSpeed Switching Network (Cray, ATM)

@item HST
Hawaiian Standard Time [-1030] (TZ)

@item HST
High Soft Tech manufacturer, ISDN

@item HST
High Speed Technology (US Robotics)

@item HT
Horizontal Tab

@item HTDM
Hybrid Time Division Multiplexing [protocol]

@item HTF
Hyper-g Text Format (Hyper-G)

@item HTH
Hope This Helps slang

@item HTML
HyperText Markup Language (Internet, WWW, SGML, RFC 1866/1942)

@item HTTP
HyperText Transfer Protocol (WWW, RFC 2068)

@item HTTPD
HyperText Transfer Protocol DAEMON (WWW, HTTP)

@item HTTPNG
HyperText Transfer Protocol - Next Generation (WWW), "HTTP-NG"

@item HUGO
Holland User Group for OS/2 Org., User group, OS/2, Netherlands

@item HURD
HIRD of Unix-Replacing DAEMONs (GNU, HIRD)

@item HVC
Hue-Value-Chroma [model] (Tektronic, DTP)

@item HVD
High Voltage Differential [technology] (SCSI)

@item HYTEA
HYperText Environment for Authoring (ESPRIT)

@item HYTIME
Hypermedia/Time-based structuring language (SGML, ISO, IEC, IS 10744), "HyTime"

@end table

==> vera-1.5.tar.gz: vera-1.5/vera.h <==
@c Syntax:
@c ACRONYM
@c Expansion[ (Reference)][, "Style"]
@c Additional explanations are included in [square brackets]

@table @asis
@item H4P
High Performance Parallel Processing Project (ICI)

@item HACMP
High Availability Clustered Multi Processing (IBM, RS/6000, Bull), "HA/CMP"

@item HAL
Hard Array Logic

@item HAL
Hardware Abstraction Layer (Windows NT)

@item HAL
Heuristically programmed ALgorithmic computer (2001)

@item HALPC
Houston Area League of PC-Users, "HAL-PC" 

@item HAMPS
Host AUTODIN Message Processing System (AUTODIN, mil.)

@item HAND
Have A Nice Day (slang, Usenet, IRC)

@item HANFS
Highly Available Network File System

@item HAP
Host Access Protocol (RFC 907/1221)

@item HAS
High Availability Subsystem (Bull)

@item HAT
Hashed Address Table

@item HBA
Host Bus Adapter (SCSI)

@item HBCI
HomeBanking Computer Interface (Internet, banking)

@item HCI
Human Computer Interaction (BCS, conference)

@item HCL
Host Control Links

@item HCSDS
High Capacity Satellite Digital Service

@item HCSS
High Capacity Storage System (Novell, Netware)

@item HCT
Hamburger ComputerTage (fair)

@item HCT
High-speed CMOS [logic] with TTT-compatible [logic] levels (IC, MOS)

@item HCTDS
High-Capacity Terrestrial Digital Service

@item HD
High Density

@item HDB
HoneyDanBer [standard] (Unix)

@item HDB3
High Density Bipolar 3

@item HDBMS
Hierarchical DataBase Management System (DBMS, DB)

@item HDC
Hard Disk Controller

@item HDCD
High Density Compact Disk (CD, Sony, Phillips)

@item HDD
Hard Disk Drive

@item HDF
Hierarchical Data Format (NCSA)

@item HDH
HDLC Distant Host

@item HDI
HOOPS Device Interface (VAGI)

@item HDL
Hardware Description Language (ASIC)

@item HDLC
High-level Data Link Control (ISO)

@item HDM
Hardware Device Module (I2O)

@item HDML
Handheld Device Markup Language (Mobile Systems, HDTP)

@item HDN
Hochgeschwindigkeits-DatenNetz

@item HDR
High availability Data Replication (Informix, DB)

@item HDR
High Dynamic Range

@item HDSL
High data / bit rate Digital Subscriber Line (BELLCORE, AT&T, DSL)

@item HDSL
High-level Data Specification Language

@item HDTP
Handheld Device Transport Protocol (Mobile Systems)

@item HDX
Half DupleX

@item HEA
Hyundai Electronics of America (manufacturer)

@item HEC
Header Error Check

@item HEC
Header Error Control (ATM)

@item HECTOR
HEterogeneous Computer TOgetheR (IBM, Uni Karlsruhe, Germany)

@item HEL
Hardware Emulation Layer

@item HEL
Header Extension Length

@item HEMT
High Electron Mobility Transistor

@item HEPNET
High Energy Physics NETwork (network)

@item HERMES
Heuristic Emergency Response Management Expert System (XPS)

@item HERODE
Handling the Electronic Representation of mixed text - image Office Documents based on ECMA standard 101 (ESPRIT, SNI, TITN, ECMA, ODA)

@item HES
Home Electronic System (SNI)

@item HFC
Hybrid Fiber Coax [network]

@item HFD
Hauptanschluss fuer Direktruf / Datenleitung (Telekom), "HfD" 

@item HFDS
Highly Functional Distributed System (MTRON)

@item HFS
Hierachical File System (Apple, CD)

@item HFT
High Function Terminal (AIX, IBM)

@item HGA
Hercules Graphics Adapter

@item HGC
Hercules Graphics Card

@item HHI
Heinrich Hertz Institut (org., Deutschland)

@item HI
Hochschulverband Informationswissenschaften (org.)

@item HIC
Human Interaction Component

@item HIC
Hybrid Integrated Circuit

@item HID
Human Interface Device (MS)

@item HIFD
HIgh capacity Floppy Disk (Sony, Fuji), "HiFD"

@item HIFI
Hypertext Interface For Information (ESPRIT)

@item HIFIVE
HIgh Fidelity Interactive Visual Environment (DEC), "Hi-FIVE"

@item HIFT
Hardware Implemented Fault Tolerance (SIFT)

@item HIGGENS
Human Interface Graphical GENeration System (Uni Colorado)

@item HINT
Hierarchical INTegration [benchmark]

@item HIPPI
HIgh Performance Parallel Interface

@item HIPPI
High Performance Peripheral Interface

@item HIRD
HURD of Interface Representing Depth (GNU, HURD)

@item HISP
HIgh SPeed channel connector (Cray, I/O)

@item HLL
High Level Language

@item HLLAPI
High Level Language Application Programming Interface (IBM, API)

@item HLPI
Higher Layer Protocol Identifier

@item HLR
Home Location Register (LR, GSM)

@item HLS
Hue, Luminance, Saturation (color system, DTP)

@item HMA
High Memory Area

@item HMAC
keyed-Hashing for Message AuthentiCation (cryptography, RFC 2104)

@item HMC
Highspeed Memory Controller (Apple)

@item HMD
Head Mounted Display (VR)

@item HMI
Human-Machine Interface

@item HMMP
HyperMedia Management Protocol (MS, Intel, Cisco, WWW, HMMS)

@item HMMS
HyperMedia Management Schema (MS, Intel, Cisco, WWW)

@item HMOS
High performance Metal Oxide Semiconductor (IC)

@item HMP
Host Monitoring Protocol (RFC 869)

@item HMUX
Hybrid MUltipleXer (FDDI), "H-MUX"

@item HNF
Heinz Nixdorf Museumsforum (org., Paderborn, Germany)

@item HNI
Heinz Nixdorf Institut (org., ZIT)

@item HOL
Head Of Line

@item HOOPS
Hierarchical Object Orientated Picture System (Ithaca, Autodesk, OOP)

@item HP
Hewlett Packard (manufacturer)

@item HPBIDS
Hewlett Packard Broadband Internet Delivery System (HP, Internet), "HP BIDS"

@item HPC
High Performance Computing

@item HPCC
High Performance Computing and Communication

@item HPCS
High Performance Communication Server (Tobit, NLM, Netware)

@item HPF
High Performance FORTRAN (FORTRAN)

@item HPFS
High Performance FileSystem (OS/2)

@item HPGL
Hewlett Packard Graphics Language (CAD, CAM, HP)

@item HPIB
Hewlett Packard Interface Bus

@item HPM
Hyper Page Mode

@item HPMI
??? [Schnittstelle] (CAD), "HP-MI"

@item HPOFS
High Performance Optical File System (IBM, OS/2, MOD)

@item HPPA
Hewlett Packard Precision Architecture (HP, RISC)

@item HPPCL
Hewlett Packard Printer Control Language

@item HPR
High Priority Request (VUMA)

@item HPTS
High Performance Transaction Systems

@item HPUX
Hewlett Packard / UniX (Unix), "HP/UX" 

@item HPVEE
Hewlett-Packard Visual Engineering Environment (HP, GUI), "HP VEE"

@item HPVUE
Hewlett Packard - Visual User Environment (HP, GUI), "HP-VUE"

@item HRC
Hybrid Ring Control (FDDI)

@item HS
High Speed (MODEM)

@item HSA
High Speed Access

@item HSB
Hue Saturation Brightness (DTP)

@item HSC
Hierarchical Storage Controller

@item HSFS
High Sierra File System

@item HSI
High Speed Interface

@item HSI
Hue, Saturation, Intensity (DTP)

@item HSIS
??? High Speed Interface / SNA, "HSI/S" 

@item HSLAN
High Speed Local Area Network, "HS-LAN" 

@item HSLFX
??? [hardware description language] (HDL, NTT, LSI), "HSL-FX"

@item HSLN
High Speed Local Network

@item HSM
Hardware Specific Module (ODI)

@item HSM
Hierarchical Storage Management

@item HSM
Hierarchisches SpeicherManagement

@item HSP
[UUNet] HighSpeed Peering

@item HSRP
Hot Standby Router Protocol (Cisco, IOS)

@item HSSDS
High-Speed Switched Digital Service

@item HSSI
High Speed Serial Interface

@item HSSN
HighSpeed Switching Network (Cray, ATM)

@item HST
Hawaiian Standard Time [-1030] (TZ)

@item HST
High Soft Tech (manufacturer, ISDN)

@item HST
High Speed Technology (US Robotics)

@item HT
Horizontal Tab

@item HTDM
Hybrid Time Division Multiplexing [protocol]

@item HTF
Hyper-g Text Format (Hyper-G)

@item HTH
Hope This Helps (slang)

@item HTML
HyperText Markup Language (Internet, WWW, SGML, RFC 1866/1942)

@item HTTP
HyperText Transfer Protocol (WWW, RFC 2068)

@item HTTPD
HyperText Transfer Protocol DAEMON (WWW, HTTP)

@item HTTPNG
HyperText Transfer Protocol - Next Generation (WWW), "HTTP-NG"

@item HTTPS
HyperText Transfer Protocol [SSL] Secured (HTTP, SSL, WWW)

@item HUGO
Holland User Group for OS/2 (org., user group, OS/2, Netherlands)

@item HURD
HIRD of Unix-Replacing DAEMONs (GNU, HIRD)

@item HVC
Hue-Value-Chroma [model] (Tektronic, DTP)

@item HVD
High Voltage Differential [technology] (SCSI)

@item HYTEA
HYperText Environment for Authoring (ESPRIT)

@item HYTIME
Hypermedia/Time-based structuring language (SGML, ISO, IEC, IS 10744), "HyTime"

@end table
